@@ -1,30 +1,30 @@
-import os
+# -*- coding: utf-8 -*-
 import fnmatch
+import os
 import py_compile
-from django.core.management.base import NoArgsCommand, CommandError
-from django.conf import settings
-from optparse import make_option
 from os.path import join as _j
 
+from django.conf import settings
+from django.core.management.base import BaseCommand, CommandError
+
 from django_extensions.management.utils import signalcommand
 
 
-class Command(NoArgsCommand):
-    option_list = NoArgsCommand.option_list + (
-        make_option('--path', '-p', action='store', dest='path',
-                    help='Specify path to recurse into'),
-    )
+class Command(BaseCommand):
     help = "Compile python bytecode files for the project."
+    requires_system_checks = False
 
-    requires_model_validation = False
+    def add_arguments(self, parser):
+        parser.add_argument('--path', '-p', action='store', dest='path',
+                            help='Specify path to recurse into')
 
     @signalcommand
-    def handle_noargs(self, **options):
-        project_root = options.get("path", None)
+    def handle(self, *args, **options):
+        project_root = options["path"]
         if not project_root:
             project_root = getattr(settings, 'BASE_DIR', None)
 
-        verbosity = int(options.get("verbosity"))
+        verbosity = options["verbosity"]
         if not project_root:
             raise CommandError("No --path specified and settings.py does not contain BASE_DIR")
 
