@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function
-
 import asyncore
 import sys
 from logging import getLogger
@@ -39,6 +37,7 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         super().add_arguments(parser)
+        parser.add_argument('addrport', nargs='?')
         parser.add_argument(
             '--output', dest='output_file', default=None,
             help='Specifies an output file to send a copy of all messages (not flushed immediately).'
@@ -78,10 +77,7 @@ class Command(BaseCommand):
         def inner_run():
             quit_command = (sys.platform == 'win32') and 'CTRL-BREAK' or 'CONTROL-C'
             print("Now accepting mail at %s:%s -- use %s to quit" % (addr, port, quit_command))
-            if sys.version_info < (3, 5):
-                ExtensionDebuggingServer((addr, port), None)
-            else:
-                ExtensionDebuggingServer((addr, port), None, decode_data=True)
+            ExtensionDebuggingServer((addr, port), None, decode_data=True)
             asyncore.loop()
 
         try:
