@@ -3,7 +3,9 @@ import inspect
 import os
 import sys
 import traceback
+import warnings
 
+from django.db import connections
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
 from django.utils.datastructures import OrderedSet
@@ -82,6 +84,10 @@ class Command(BaseCommand):
             default=False,
             help="Print SQL queries as they're executed"
         )
+        parser.add_argument(
+            '--truncate-sql', action='store', type=int,
+            help="Truncate SQL queries to a number of characters."
+        )
         parser.add_argument(
             '--print-sql-location', action='store_true',
             default=False,
@@ -202,7 +208,7 @@ class Command(BaseCommand):
 
         return {'django_extensions': ks}
 
-    def run_notebookapp(self, app, options, use_kernel_specs=True):
+    def run_notebookapp(self, app_init, options, use_kernel_specs=True, history=True):
         no_browser = options['no_browser']
 
         if self.extra_args:
@@ -233,7 +239,16 @@ class Command(BaseCommand):
         if not use_kernel_specs:
             notebook_arguments.extend(ipython_arguments)
 
-        app.initialize(notebook_arguments)
+        # disable history if not already configured in some other way
+        if not history and not any(arg.startswith('--HistoryManager') for arg in ipython_arguments):
+            ipython_arguments.append('--HistoryManager.enabled=False')
+
+        if not callable(app_init):
+            app = app_init
+            warnings.warn('Initialize should be a callable not an app instance', DeprecationWarning)
+            app.initialize(notebook_arguments)
+        else:
+            app = app_init(notebook_arguments)
 
         # IPython >= 3 uses kernelspecs to specify kernel CLI args
         if use_kernel_specs:
@@ -284,10 +299,13 @@ class Command(BaseCommand):
 
         use_kernel_specs = release.version_info[0] >= 3
 
-        def run_notebook():
+        def app_init(*args, **kwargs):
             app = NotebookApp.instance()
-            self.run_notebookapp(app, options, use_kernel_specs)
+            app.initialize(*args, **kwargs)
+            return app
 
+        def run_notebook():
+            self.run_notebookapp(app_init, options, use_kernel_specs)
         return run_notebook
 
     @shell_runner(flags=['--lab'], name='JupyterLab Notebook')
@@ -297,10 +315,22 @@ class Command(BaseCommand):
         except ImportError:
             return traceback.format_exc()
 
-        def run_jupyterlab():
-            app = LabApp.instance()
-            self.run_notebookapp(app, options)
+        # check for JupyterLab 3.0
+        try:
+            from notebook.notebookapp import NotebookApp
+        except ImportError:
+            NotebookApp = None
 
+        if not NotebookApp or not issubclass(LabApp, NotebookApp):
+            app_init = LabApp.initialize_server
+        else:
+            def app_init(*args, **kwargs):
+                app = LabApp.instance()
+                app.initialize(*args, **kwargs)
+                return app
+
+        def run_jupyterlab():
+            self.run_notebookapp(app_init, options, history=False)
         return run_jupyterlab
 
     @shell_runner(flags=['--plain'], name='plain Python')
@@ -460,29 +490,20 @@ for k, m in shells.import_objects({}, no_style()).items():
 
         http://www.postgresql.org/docs/9.4/static/libpq-connect.html#LIBPQ-PARAMKEYWORDS  # noqa
         """
-        supported_backends = ['django.db.backends.postgresql',
-                              'django.db.backends.postgresql_psycopg2']
+        supported_backends = (
+            'django.db.backends.postgresql',
+            'django.db.backends.postgresql_psycopg2',
+        )
         opt_name = 'fallback_application_name'
         default_app_name = 'django_shell'
-        app_name = default_app_name
         dbs = getattr(settings, 'DATABASES', [])
 
-        # lookup over all the databases entry
-        for db in dbs.keys():
-            if dbs[db]['ENGINE'] in supported_backends:
-                try:
-                    options = dbs[db]['OPTIONS']
-                except KeyError:
-                    options = {}
-
-                # dot not override a defined value
-                if opt_name in options.keys():
-                    app_name = dbs[db]['OPTIONS'][opt_name]
-                else:
-                    dbs[db].setdefault('OPTIONS', {}).update({opt_name: default_app_name})
-                    app_name = default_app_name
-
-        return app_name
+        for connection in connections.all():
+            alias = connection.alias
+            mro = inspect.getmro(connection.__class__)
+            if any(klass.__module__.startswith(supported_backends) for klass in mro):
+                if 'OPTIONS' not in dbs[alias] or opt_name not in dbs[alias]['OPTIONS']:
+                    dbs[alias].setdefault('OPTIONS', {}).update({opt_name: default_app_name})
 
     @signalcommand
     def handle(self, *args, **options):
@@ -491,8 +512,9 @@ for k, m in shells.import_objects({}, no_style()).items():
         print_sql = getattr(settings, 'SHELL_PLUS_PRINT_SQL', False)
         runner = None
         runner_name = None
+        truncate = None if options["truncate_sql"] == 0 else options["truncate_sql"]
 
-        with monkey_patch_cursordebugwrapper(print_sql=options["print_sql"] or print_sql, print_sql_location=options["print_sql_location"], confprefix="SHELL_PLUS"):
+        with monkey_patch_cursordebugwrapper(print_sql=options["print_sql"] or print_sql, truncate=truncate, print_sql_location=options["print_sql_location"], confprefix="SHELL_PLUS"):
             SETTINGS_SHELL_PLUS = getattr(settings, 'SHELL_PLUS', None)
 
             def get_runner_by_flag(flag):
@@ -558,7 +580,7 @@ for k, m in shells.import_objects({}, no_style()).items():
 
             if options['command']:
                 imported_objects = self.get_imported_objects(options)
-                exec(options['command'], {}, imported_objects)
-                return
+                exec(options['command'], imported_objects)
+                return None
 
             runner()
