@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-import six
+import sys
 from django.contrib.auth.models import Group, Permission
 from django.test import override_settings
 
@@ -151,7 +151,7 @@ class CRTestCase(AutomaticShellPlusImportsTestCase):
         SHELL_PLUS_MODEL_IMPORTS_RESOLVER='tests.management.commands.shell_plus_tests.test_collision_resolver.TestAppsOrderCR',
     )
     def test_installed_bad_order_collision_resolver(self):
-        with six.assertRaisesRegex(self, AssertionError, "You must define APP_PRIORITIES in your resolver class!"):
+        with self.assertRaisesRegex(AssertionError, "You must define APP_PRIORITIES in your resolver class!"):
             self._assert_models_present_under_names(
                 set(), set(), set(), set(), set(), set(), set(), set(), set(), set(), set(),
             )
@@ -160,13 +160,13 @@ class CRTestCase(AutomaticShellPlusImportsTestCase):
         SHELL_PLUS_MODEL_IMPORTS_RESOLVER='tests.management.commands.shell_plus_tests.test_collision_resolver.TestAppNameCR',
     )
     def test_installed_apps_bad_name_collision_resolver(self):
-        with six.assertRaisesRegex(self, AssertionError, "You must define MODIFICATION_STRING in your resolver class!"):
+        with self.assertRaisesRegex(AssertionError, "You must define MODIFICATION_STRING in your resolver class!"):
             self._assert_models_present_under_names(
                 set(), set(), set(), set(), set(), set(), set(), set(), set(), set(), set(),
             )
 
     def _assert_bad_resolver(self, message):
-        with six.assertRaisesRegex(self, AssertionError, message):
+        with self.assertRaisesRegex(AssertionError, message):
             self._assert_models_present_under_names(
                 set(), set(), set(), set(), set(), set(), set(), set(), set(), set(), set(),
             )
@@ -187,9 +187,10 @@ class CRTestCase(AutomaticShellPlusImportsTestCase):
         SHELL_PLUS_MODEL_IMPORTS_RESOLVER='tests.management.commands.shell_plus_tests.test_collision_resolver.CRNoFunction',
     )
     def test_installed_apps_no_resolve_conflicts_function(self):
-        with six.assertRaisesRegex(
-            self, TypeError, "Can't instantiate abstract class CRNoFunction with abstract methods resolve_collisions"
-        ):
+        exception_msg = "Can't instantiate abstract class CRNoFunction with abstract methods resolve_collisions"
+        if sys.version_info[:2] >= (3, 9):
+            exception_msg = exception_msg.replace('methods', 'method')
+        with self.assertRaisesRegex(TypeError, exception_msg):
             self._assert_models_present_under_names(
                 set(), set(), set(), set(), set(), set(), set(), set(), set(), set(), set(),
             )
