@@ -1,20 +1,16 @@
 # -*- coding: utf-8 -*-
 import os
-import six
 import shutil
 
 from django.conf import settings
 from django.core.management import CommandError, call_command
 from django.test import TestCase
 from django.test.utils import override_settings
-from six import StringIO
+from io import StringIO
 
 from django_extensions.management.commands.sync_s3 import Command
 
-try:
-    from unittest.mock import Mock, patch
-except ImportError:
-    from mock import Mock, patch
+from unittest.mock import Mock, patch
 
 
 class SyncS3TestsMixin():
@@ -34,17 +30,17 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
 
     def test_should_raise_ImportError_if_boto_is_not_installed(self):
         with patch('django_extensions.management.commands.sync_s3.HAS_BOTO', False):
-            with six.assertRaisesRegex(self, CommandError, r"Please install the 'boto' Python library. \(\$ pip install boto\)"):
+            with self.assertRaisesRegex(CommandError, r"Please install the 'boto' Python library. \(\$ pip install boto\)"):
                 call_command('sync_s3')
 
     @override_settings(AWS_ACCESS_KEY_ID=None)
     def test_should_raise_CommandError_if_AWS_ACCESS_KEY_ID_is_not_set_or_is_set_to_None(self):
-        with six.assertRaisesRegex(self, CommandError, "Missing AWS keys from settings file.  Please supply both AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY"):
+        with self.assertRaisesRegex(CommandError, "Missing AWS keys from settings file.  Please supply both AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY"):
             call_command('sync_s3')
 
     @override_settings(AWS_SECRET_ACCESS_KEY=None)
     def test_should_raise_CommandError_if_AWS_SECRET_ACCESS_KEY_is_not_set_or_is_set_to_None(self):
-        with six.assertRaisesRegex(self, CommandError, "Missing AWS keys from settings file.  Please supply both AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY"):
+        with self.assertRaisesRegex(CommandError, "Missing AWS keys from settings file.  Please supply both AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY"):
             call_command('sync_s3')
 
     @override_settings(
@@ -53,7 +49,7 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
         AWS_BUCKET_NAME=''
     )
     def test_should_raise_CommandError_if_AWS_BUCKET_NAME_is_set_to_None(self):
-        with six.assertRaisesRegex(self, CommandError, "AWS_BUCKET_NAME cannot be empty"):
+        with self.assertRaisesRegex(CommandError, "AWS_BUCKET_NAME cannot be empty"):
             call_command('sync_s3')
 
     @override_settings(
@@ -63,7 +59,7 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
     def test_should_raise_CommandError_if_AWS_BUCKET_NAME_does_not_have_AWS_BUCKET_NAME_attr(self):
         del settings.AWS_BUCKET_NAME
 
-        with six.assertRaisesRegex(self, CommandError, "Missing bucket name from settings file. Please add the AWS_BUCKET_NAME to your settings file."):
+        with self.assertRaisesRegex(CommandError, "Missing bucket name from settings file. Please add the AWS_BUCKET_NAME to your settings file."):
             call_command('sync_s3')
 
     @override_settings(
@@ -73,7 +69,7 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
         MEDIA_ROOT=None
     )
     def test_should_raise_CommandError_if_MEDIA_ROOT_is_None(self):
-        with six.assertRaisesRegex(self, CommandError, "MEDIA_ROOT must be set in your settings."):
+        with self.assertRaisesRegex(CommandError, "MEDIA_ROOT must be set in your settings."):
             call_command('sync_s3')
 
     @override_settings(
@@ -84,7 +80,7 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
     def test_should_raise_CommandError_if_settings_does_not_have_MEDIA_ROOT_attr(self):
         del settings.MEDIA_ROOT
 
-        with six.assertRaisesRegex(self, CommandError, "MEDIA_ROOT must be set in your settings."):
+        with self.assertRaisesRegex(CommandError, "MEDIA_ROOT must be set in your settings."):
             call_command('sync_s3')
 
     @override_settings(
@@ -93,7 +89,7 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
         AWS_BUCKET_NAME='bucket_name',
     )
     def test_should_raise_CommandError_when_media_only_and_static_only_options_together(self):
-        with six.assertRaisesRegex(self, CommandError, "Can't use --media-only and --static-only together. Better not use anything..."):
+        with self.assertRaisesRegex(CommandError, "Can't use --media-only and --static-only together. Better not use anything..."):
             call_command('sync_s3', '--media-only', '--static-only')
 
     @override_settings(
@@ -108,7 +104,7 @@ class SyncS3ExceptionsTests(SyncS3TestsMixin, TestCase):
         self.m_boto.connect_s3.return_value.get_bucket.return_value = m_bucket
         self.m_boto.s3.key.Key.return_value = 'bucket_key'
 
-        with six.assertRaisesRegex(self, CommandError, "An object invalidation was requested but the variable AWS_CLOUDFRONT_DISTRIBUTION is not present in your settings."):
+        with self.assertRaisesRegex(CommandError, "An object invalidation was requested but the variable AWS_CLOUDFRONT_DISTRIBUTION is not present in your settings."):
             call_command('sync_s3', '--media-only', '--invalidate')
 
 
