@@ -1,10 +1,7 @@
 # -*- coding: utf-8 -*-
 from django_extensions.management.jobs import DailyJob
 
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 
 
 DAILY_JOB_MOCK = mock.MagicMock()
